Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(281)

Unified Diff: ash/system/tray/tray_popup_utils.h

Issue 2831023003: Refactor AddScrollListItem() in system menu detailed views (Closed)
Patch Set: Cleanup Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/system/tray/tray_popup_utils.h
diff --git a/ash/system/tray/tray_popup_utils.h b/ash/system/tray/tray_popup_utils.h
index d674034c8b8e9384d5e47dcfcc3440aa56f77191..a632044acb07f8ebb2fdb2978262e49512e18ec5 100644
--- a/ash/system/tray/tray_popup_utils.h
+++ b/ash/system/tray/tray_popup_utils.h
@@ -54,13 +54,15 @@ class TrayPopupUtils {
// Creates a container view to be used by system menu sub-section header rows.
// The caller takes over ownership of the created view.
//
- // The returned view consists of 2 regions: CENTER, and END having the same
- // properties as when using |CreateMultiTargetRowView|. The START container is
- // hidden.
- // The END container has a fixed minimum width but can grow into the CENTER
- // container if space is required and available. The CENTER container has a
- // flexible width.
- static TriView* CreateSubHeaderRowView();
+ // The returned view contains at least CENTER and END regions having the same
+ // properties as when using |CreateMultiTargetRowView|. |hide_start|
+ // determines whether the START region should be visible or not. If START is
+ // not visible, padding would be increased on that side.
tdanderson 2017/04/24 15:43:39 I'm not sure about the last sentence here. If STAR
mohsen 2017/04/25 05:10:01 What I meant is that when START is not visible, we
+ //
+ // The START (if visible) and END containers have a fixed minimum width but
+ // can grow into the CENTER container if space is required and available. The
+ // CENTER container has a flexible width.
+ static TriView* CreateSubHeaderRowView(bool hide_start);
tdanderson 2017/04/24 15:43:39 optional: I don't think this is called out explici
mohsen 2017/04/25 05:10:02 Makes sense. Done.
// Creates a view containing only a label (corresponding to |message_id|),
// which is to be inserted as a non-targetable row within a system menu

Powered by Google App Engine
This is Rietveld 408576698